"""
This module contains utilities sharing by various IO components.
"""

from typing import Sequence


DEFAULT_NEWLINE = '\r\n'


def bool_to_string(value: bool) -> str:
    """ Convert given boolean to its lowercase string representation """
    if value is True:
        return 'true'
    elif value is False:
        return 'false'
    else:
        raise ValueError('{value} is not bool!'.format(value=value))


def float_to_string(value: float, precision: int=5) -> str:
    """ Convert float to string with given precision and remove trailing zeroes """
    # TODO: Make precision kwarg usable, now the value is hardcoded
    stringified = '{:.5f}'.format(value)
    stringified = stringified.rstrip('0').rstrip('.')
    return stringified


def float_sequence_to_string(sequence: Sequence[float], precision: int=5) -> str:
    """ Join sequence elements with spaces and stringify floats with given precision """
    stringified_floats = (float_to_string(value, precision) for value in sequence)
    stringified_sequence = " ".join(stringified_floats)
    return stringified_sequence


def bool_from_string(string: str) -> bool:
    """ Return boolean value readed from its string representation """
    string = string.lower()
    if string == 'true':
        return True
    elif string == 'false':
        return False
    else:
        raise ValueError(
            'Cannot make boolean value from string {string}'.format(string=string)
        )
